@@ -25,7 +25,6 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <gconf/gconf-client.h>
 #include "gok-data.h"
 #include "gok-log.h"
 #include "gok-gconf.h"
@@ -120,6 +119,13 @@ void gok_data_initialize ()
 	m_bSettingsChanged = FALSE;
 }
 
+GConfClient*
+gok_data_get_gconf_client ()
+{
+	return gconf_client;
+}
+
+
 static GokDockType
 gok_data_dock_type_from_string (gchar *string)
 {
