@@ -32,7 +32,8 @@ extern "C" {
 /* all possible calls used in all access methods */
 /* Don't change the order of these unless you also update ArrayCallNames */
 typedef enum {
-CALL_CHUNKER_RESET,  /* not really used */
+CALL_CHUNKER_RESET,
+CALL_CHUNKER_CHUNK_NONE,
 CALL_CHUNKER_CHUNK_ROWS,
 CALL_CHUNKER_CHUNK_COLUMNS,
 CALL_CHUNKER_NEXT_CHUNK,
@@ -261,6 +262,7 @@ void gok_scanner_on_switch4_up (void);
 void gok_scanner_on_switch5_down (void);
 void gok_scanner_on_switch5_up (void);
 void gok_scanner_repeat_on(void);
+void gok_scanner_drop_refs (GokKey *pKey);
 
 #ifdef __cplusplus
 }
